@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2021 Statnet Commons
+#  Copyright 2003-2022 Statnet Commons
 ################################################################################
 #===========================================================================
 # The <InitErgmProposal> file contains the following 24 functions for
@@ -43,14 +43,38 @@
 ############################################################################
 DyadGenType <- list(RandDyadGen=0L, WtRandDyadGen=1L, RLEBDM1DGen=2L, EdgeListGen=3L)
 
+#' @templateVar name randomtoggle
+#' @aliases InitErgmProposal.randomtoggle
+#' @title Propose a randomly selected dyad to toggle
+#' @description Propose a randomly selected dyad to toggle
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.randomtoggle <- function(arguments, nw){
   list(name = "randomtoggle", dyadgen = ergm_dyadgen_select(arguments, nw), bd = ergm_bd_init(arguments, nw))
 }
 
+#' @templateVar name TNT
+#' @aliases InitErgmProposal.TNT
+#' @title Default MH algorithm
+#' @description Stratifies the population of dyads
+#'   edge status: those having ties and those having no ties (hence T/NT).
+#'   This is useful for improving performance in sparse networks,
+#'   because it gives at least 50\% chance of proposing a toggle of an existing edge.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.TNT <- function(nw, arguments, ...){
   list(name = "TNT", dyadgen = ergm_dyadgen_select(arguments, nw), bd = ergm_bd_init(arguments, nw))
 }
 
+#' @templateVar name BDStratTNT
+#' @aliases InitErgmProposal.BDStratTNT
+#' @title TNT proposal with degree bounds
+#' @description Implements a TNT proposal with any subset of the following features:
+#'   1. upper on degree, specified via the [`bd`][bd-ergmConstraint] constraint's `maxout`, `maxin`, and `attribs` arguments
+#'   2. stratification of proposals according to mixing type on a vertex attribute, specified via the [`strat`][strat-ergmHint] hint;
+#'   3. fixation of specified mixing types on a(nother) vertex attribute, specified via the [`blocks`][blocks-ergmConstraint] constraint.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.BDStratTNT <- function(arguments, nw) {
   # if bd has not already been initialized, or if related arguments are passed directly to the proposal, (re)initialize it now
   if(any(!unlist(lapply(arguments[c("attribs", "maxout", "maxin")], is.null)))) {
@@ -201,16 +225,41 @@ InitErgmProposal.BDStratTNT <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name CondDegree
+#' @aliases InitErgmProposal.CondDegree
+#' @title MHp for degree constraints
+#' @description MHp for \eqn{constraints= ~degree}. Propose either 4 toggles (MH_CondDegreeTetrad) or 6 toggles
+#'   (MH_CondDegreeHexad) at once. For undirected networks, propose 4 toggles (MH_CondDegreeTetrad).
+#'   MH_CondDegreeTetrad selects two edges with no nodes in common, A1-A2 and B1-B2, s.t. A1-B2 and B1-A2 are
+#'   not edges, and propose to replace the former two by the latter two. MH_CondDegreeHexad selects three edges
+#'   A1->A2, B1->B2, C1->C2 at random and rotate them to A1->B2, B1->C2, and C1->A2.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondDegree <- function(arguments, nw) {
   proposal <- list(name = "CondDegree", inputs=NULL)
   proposal
 }
+
+#' @templateVar name CondDegreeMix
+#' @aliases InitErgmProposal.CondDegreeMix
+#' @title MHp for degree mix constraints
+#' @description MHp for \eqn{constraints= ~degreesmix}. Similar to `InitErgmProposal.CondDegree`, except that
+#'   the toggle is proposed only if the mixing matrix of degrees is preserved before and after the toggle.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondDegreeMix <- function(arguments, nw) {
   proposal <- list(name = "CondDegreeMix",
     inputs=get.vertex.attribute(nw,arguments$constraints$degreesmix$attrib))
   proposal
 }
 
+#' @templateVar name CondOutDegree
+#' @aliases InitErgmProposal.CondOutDegree
+#' @title MHp for odegree constraints
+#' @description MHp for \eqn{constraints= ~odegrees}. For directed networks, randomly select two dyads with a
+#'   common tail node, one having an edge and one not, and propose to swap the tie from one head to the other.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondOutDegree <- function(arguments, nw) {
   proposal <- list(name = "CondOutDegree", inputs=NULL)
   if (!is.directed(nw)) # Really, this should never trigger, since the InitErgmConstraint function should check.
@@ -219,6 +268,13 @@ InitErgmProposal.CondOutDegree <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name CondInDegree
+#' @aliases InitErgmProposal.CondInDegree
+#' @title MHp for idegree constraints
+#' @description MHp for \eqn{constraints= ~idegrees}. For directed networks, randomly select two dyads with a
+#'   common head node, one having an edge one not, and propose to swap the tie from one tail to the other.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondInDegree <- function(arguments, nw) {
   proposal <- list(name = "CondInDegree", inputs=NULL)
   if (!is.directed(nw)) # Really, this should never trigger, since the InitErgmConstraint function should check.
@@ -227,6 +283,14 @@ InitErgmProposal.CondInDegree <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name CondB1Degree
+#' @aliases InitErgmProposal.CondB1Degree
+#' @title MHp for b1degree constraints
+#' @description MHp for \eqn{constraints= ~b1degrees}. For bipartite networks, randomly select an edge {B1i, B2j}
+#'   and an empty dyad with the same node B1i, {B1i, B2k}, and propose to toggle both {B1i, B2j} and {B1i, B2k}.
+#'   This ensures that the degrees of individual nodes in mode 1 are preserved.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondB1Degree <- function(arguments, nw) {
   proposal <- list(name = "CondB1Degree", inputs=NULL)
   if (!is.bipartite(nw)) # Really, this should never trigger, since the InitErgmConstraint function should check.
@@ -235,6 +299,14 @@ InitErgmProposal.CondB1Degree <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name CondB2Degree
+#' @aliases InitErgmProposal.CondB2Degree
+#' @title MHp for b2degree constraints
+#' @description MHp for \eqn{constraints= ~b2degrees}. For bipartite networks, randomly select an edge {B1j, B2i}
+#'   and an empty dyad with the same node B2i, {B1k, B2i}, and propose to toggle both {B1j, B2i} and {B1k, B2i}.
+#'   This ensures that the degrees of individual nodes in mode 2 are preserved.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondB2Degree <- function(arguments, nw) {
   proposal <- list(name = "CondB2Degree", inputs=NULL)
   if (!is.bipartite(nw)) # Really, this should never trigger, since the InitErgmConstraint function should check.
@@ -242,6 +314,14 @@ InitErgmProposal.CondB2Degree <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name CondDegreeDist
+#' @aliases InitErgmProposal.CondDegreeDist
+#' @title MHp for degreedist constraints
+#' @description MHp for \eqn{constraints= ~degreedist}. Randomly select a node (T) and its edge (E).  If the head
+#'   node of the edge (H) has 1 degree more than another randomly select node (A), and A is disconnected to both
+#'   T and H, then propose to toggle E and the dyad between T and A.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondDegreeDist <- function(arguments, nw) {
   proposal <- list(name = "CondDegreeDist", inputs=NULL)
   if (is.directed(nw)) {
@@ -255,6 +335,13 @@ InitErgmProposal.CondDegreeDist <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name CondInDegreeDist
+#' @aliases InitErgmProposal.CondInDegreeDist
+#' @title MHp for idegreedist constraints
+#' @description MHp for \eqn{constraints= ~idegreedist}. For directed networks, similar to
+#'   `InitErgmProposal.CondDegreeDist`, except for indegree case
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondInDegreeDist <- function(arguments, nw) {
   proposal <- list(name = "CondInDegreeDist", inputs=NULL)
   if (!is.directed(nw)) {
@@ -268,6 +355,13 @@ InitErgmProposal.CondInDegreeDist <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name CondOutDegreeDist
+#' @aliases InitErgmProposal.CondOutDegreeDist
+#' @title MHp for odegreedist constraints
+#' @description MHp for \eqn{constraints= ~odegreedist}. For directed networks, similar to
+#'   `InitErgmProposal.CondDegreeDist`, except for outdegree case
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.CondOutDegreeDist <- function(arguments, nw) {
   proposal <- list(name = "CondOutDegreeDist", inputs=NULL)
   if (!is.directed(nw)) {
@@ -282,11 +376,29 @@ InitErgmProposal.CondOutDegreeDist <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name ConstantEdges
+#' @aliases InitErgmProposal.ConstantEdges
+#' @title MHp for edges constraints
+#' @description MHp for \eqn{constraints= ~edges}. Propose pairs of toggles that keep number of edges the same.
+#'   This is done by:
+#'   a. choosing an existing edge at random;
+#'   b. repeatedly choosing dyads at random until one is found that does not have an edge; and
+#'   c. proposing toggling both these dyads. Note that step b. will be very inefficient if the network is nearly
+#'      complete, so this proposal is NOT recommended for such networks. However, most network datasets are
+#'      sparse, so this is not likely to be an issue.
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.ConstantEdges <- function(arguments, nw) {
   proposal <- list(name = "ConstantEdges", bd = ergm_bd_init(arguments, nw))
   proposal
 }
 
+#' @templateVar name HammingConstantEdges
+#' @aliases InitErgmProposal.HammingConstantEdges
+#' @title TODO
+#' @description TODO
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.HammingConstantEdges <- function(arguments, nw) {
   proposal <- list(name = "HammingConstantEdges", inputs=NULL)
   if(is.bipartite(nw)){
@@ -295,6 +407,12 @@ InitErgmProposal.HammingConstantEdges <- function(arguments, nw) {
   proposal
 }
 
+#' @templateVar name HammingTNT
+#' @aliases InitErgmProposal.HammingTNT
+#' @title TODO
+#' @description TODO
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.HammingTNT <- function(arguments, nw) {
   proposal <- list(name = "HammingTNT", inputs=NULL)
   if(is.bipartite(nw)){
