@@ -5,8 +5,15 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2021 Statnet Commons
+#  Copyright 2003-2022 Statnet Commons
 ################################################################################
+
+#' @templateVar name dyadnoiseTNT
+#' @aliases InitErgmProposal.dyadnoiseTNT
+#' @title TODO
+#' @description TODO
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.dyadnoiseTNT<-function(arguments, nw){
   p0to1 <- arguments$constraints$dyadnoise$p01
   p1to0 <- arguments$constraints$dyadnoise$p10
@@ -22,6 +29,12 @@ InitErgmProposal.dyadnoiseTNT<-function(arguments, nw){
        bd = ergm_bd_init(arguments, nw))
 }
 
+#' @templateVar name dyadnoise
+#' @aliases InitErgmProposal.dyadnoise
+#' @title TODO
+#' @description TODO
+#' @template ergmProposal-general
+NULL
 InitErgmProposal.dyadnoise<-function(arguments, nw){
   p0to1 <- arguments$constraints$dyadnoise$p01
   p1to0 <- arguments$constraints$dyadnoise$p10
