@@ -5,12 +5,11 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2003-2021 Statnet Commons
+#  Copyright 2003-2022 Statnet Commons
 ################################################################################
 #============================================================================
 # This file contains the following 2 functions for logistic regression
 #        <ergm.logitreg>
-#        <ergm.logisticdeviance>
 #============================================================================
 
 
@@ -37,8 +36,7 @@
 # --RETURNED--
 #   fit: the best fit, as found by the <optim> function, and as a list of:
 #        par         :  the best set of parameters found
-#        value       :  the logistic deviance, as computed by
-#                       <ergm.logisticdeviance> evaluated at 'par'
+#        value       :  the logistic deviance
 #        counts      :  a two-element vector giving the number of calls to the
 #                       <ergm.locisticdeviance> function and the gradient
 #                       function for the "BFGS" method; this excludes calls
@@ -139,18 +137,9 @@ ergm.logitreg <- function(x, y, wt = rep(1, length(y)),
   names(fit$coefficients) <- dn[if(!is.null(m)) !m$etamap$offsettheta else TRUE]
   fit$deviance <- -2*fit$value
   fit$iter <- fit$iterations
-  asycov <- ginv(-fit$hessian)
+  asycov <- sginv(-fit$hessian)
   fit$cov.unscaled <- asycov
   if(!fit$converged)
       message("Trust region algorithm did not converge.")
-  invisible(fit)
+  fit
 }
-
-
-
-ergm.logisticdeviance <- function(theta, X, y,
-                            w=rep(1,length(y)), offset=rep(0,length(y)), etamap=identity, etagrad=NULL) {
-      p <- plogis(.multiply.with.inf(X,etamap(theta))+offset)
-      -2*sum(w * ifelse(y, log(p), log1p(-p)))
-}
-
