@@ -177,14 +177,18 @@ shrink_into_CH <- function(p, M, m = NULL, verbose=FALSE, ..., solver = c("glpk"
   lb <- rep.int(-Inf, d)
 
   if(solver == "lpsolve"){
-    # Set up the optimisation problem: the following are common for all rows of p.
-    lprec <- make.lp(n, d)
-    for(k in seq_len(d)) set.column(lprec, k, M[, k])
-    set.constr.type(lprec, dir)
-    set.rhs(lprec,  rhs)
-    # By default, z are bounded >= 0. We need to remove these bounds.
-    set.bounds(lprec, lower=lb)
-    lp.control(lprec, verbose=c("important","important","important","normal","detailed")[min(max(verbose+1,0),5)], ...)
+    setup.lp <- function(){
+      # Set up the optimisation problem: the following are common for all rows of p.
+      lprec <- make.lp(n, d)
+      for(k in seq_len(d)) set.column(lprec, k, M[, k])
+      set.constr.type(lprec, dir)
+      set.rhs(lprec,  rhs)
+      # By default, z are bounded >= 0. We need to remove these bounds.
+      set.bounds(lprec, lower=lb)
+      lp.control(lprec, verbose=c("important","important","important","normal","detailed")[min(max(verbose+1,0),5)], ...)
+      lprec
+    }
+    lprec <- setup.lp()
   }else{
     # Rglpk prefers this format.
     M <- slam::as.simple_triplet_matrix(M)
@@ -197,8 +201,28 @@ shrink_into_CH <- function(p, M, m = NULL, verbose=FALSE, ..., solver = c("glpk"
     if (all(abs((x <- p[i,])) <= sqrt(.Machine$double.eps))) next # Test point is at centroid. TODO: Allow the user to specify tolerance?
 
     if(solver == "lpsolve"){
-      set.objfn(lprec, x)
-      solve(lprec)
+      # Keep trying until results are satisfactory.
+      #
+      # flag meanings:
+      # -1      : dummy value, just starting out
+      #  0 or 11: Good (either 0 or some negative value)
+      #  1 or  7: Timeout
+      #  3      : Unbounded: sometimes happens and solved by reinitializing
+      #   others: probably nothing good, but don't know how to handle
+      flag <- -1
+      while(flag%in%c(-1,1,7,3)){
+        set.objfn(lprec, x)
+        flag <- solve(lprec)
+        if(flag %in% c(1,7)){ # Timeout
+          timeout <- timeout * 2 # Increase timeout, in case it's just a big problem.
+          z <- rnorm(1) # Shift target and test set by the same constant.
+          p <- p + z
+          M <- M + z
+          lprec <- setup.lp() # Reinitialize
+        }else if(flag == 3){ # Unbounded
+          lprec <- setup.lp() # Reinitialize
+        }
+      }
       o <- get.objective(lprec)
     }else{
       o <- Rglpk::Rglpk_solve_LP(x, M, dir, rhs, list(lower=list(ind=seq_len(d), val=lb)), control=list(..., verbose=max(0,verbose-3)))$optimum
