@@ -1,14 +1,12 @@
-/*  File inst/include/ergm_edgetree_common.do_not_include_directly.h in package ergm, part of the Statnet suite
- *  of packages for network analysis, https://statnet.org .
+/*  File inst/include/ergm_edgetree_common.do_not_include_directly.h in package ergm, part of the
+ *  Statnet suite of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  https://statnet.org/attribution
+ *  https://statnet.org/attribution .
  *
- *  Copyright 2003-2020 Statnet Commons
+ *  Copyright 2003-2022 Statnet Commons
  */
-#ifndef _ERGM_EDGETREE_COMMON_H_
-#define  _ERGM_EDGETREE_COMMON_H_
 #include <math.h>
 #include <R.h>
 #include <Rinternals.h>
@@ -55,13 +53,3 @@
       *(head) = tmp;							\
     }									\
   }
-
-/* Dur_Inf is a structure containing information about durations of
-edges in a network structure.
-*/ 
-typedef struct Dur_Infstruct {
-  int time;
-  int *lasttoggle;
-} Dur_Inf;
-
-#endif // _ERGM_EDGETREE_COMMON_H_
